==> ejc-credentials-impl-3.0.0-20220523.080402-30-sources.jar: com/ejianc/certify/vo/CorpCertifBVO.java <==
package com.ejianc.certify.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 证件借用配件-表体
 * 
 * @author generator
 * 
 */
public class CorpCertifBVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Integer crowno; // 行号
    private Date ts; // 时间戳
    private Long pkCorpcertify; // 主表主键
    private Long pkCorpcertifapplyB; // 借证申请单子表主键
    private Long pkCertiftype; // 申请证书类别
    private Integer certifnum; // 证书数量
    private String isjyyj; // 1-原件  2-扫描件
    private Long beianArea; // 备案区域(人力公司)
    private Long bjgw; // 报建岗位
    private String ismany; // 能否一证多用
    private String isyz; // 是否需要押证
    private String islock; // 是否锁定
    private String jydate; // 借用日期
    private String planReturnDate; // 预计归还日期
    private String vmemo; // 备注
    private String pjpsn; // 拟用证件，以逗号分隔
    private String vdef1; // 
    private String vdef10; // 
    private String vdef2; // 
    private String vdef3; // 
    private String vdef4; // 
    private String vdef5; // 
    private String vdef6; // 
    private String vdef7; // 
    private String vdef8; // 
    private String vdef9; // 
    private String useage; // 用途
    

    public Integer getCrowno() {
        return crowno;
    }

    public void setCrowno(Integer crowno) {
        this.crowno = crowno;
    }
    public Date getTs() {
        return ts;
    }

    public void setTs(Date ts) {
        this.ts = ts;
    }
    public Long getPkCorpcertify() {
        return pkCorpcertify;
    }

    public void setPkCorpcertify(Long pkCorpcertify) {
        this.pkCorpcertify = pkCorpcertify;
    }
    public Long getPkCorpcertifapplyB() {
        return pkCorpcertifapplyB;
    }

    public void setPkCorpcertifapplyB(Long pkCorpcertifapplyB) {
        this.pkCorpcertifapplyB = pkCorpcertifapplyB;
    }
    public Long getPkCertiftype() {
        return pkCertiftype;
    }

    public void setPkCertiftype(Long pkCertiftype) {
        this.pkCertiftype = pkCertiftype;
    }
    public Integer getCertifnum() {
        return certifnum;
    }

    public void setCertifnum(Integer certifnum) {
        this.certifnum = certifnum;
    }
    public String getIsjyyj() {
        return isjyyj;
    }

    public void setIsjyyj(String isjyyj) {
        this.isjyyj = isjyyj;
    }
    public Long getBeianArea() {
        return beianArea;
    }

    public void setBeianArea(Long beianArea) {
        this.beianArea = beianArea;
    }
    public Long getBjgw() {
        return bjgw;
    }

    public void setBjgw(Long bjgw) {
        this.bjgw = bjgw;
    }
    public String getIsmany() {
        return ismany;
    }

    public void setIsmany(String ismany) {
        this.ismany = ismany;
    }
    public String getIsyz() {
        return isyz;
    }

    public void setIsyz(String isyz) {
        this.isyz = isyz;
    }
    public String getIslock() {
        return islock;
    }

    public void setIslock(String islock) {
        this.islock = islock;
    }
    public String getJydate() {
        return jydate;
    }

    public void setJydate(String jydate) {
        this.jydate = jydate;
    }
    public String getPlanReturnDate() {
        return planReturnDate;
    }

    public void setPlanReturnDate(String planReturnDate) {
        this.planReturnDate = planReturnDate;
    }
    public String getVmemo() {
        return vmemo;
    }

    public void setVmemo(String vmemo) {
        this.vmemo = vmemo;
    }
    public String getPjpsn() {
        return pjpsn;
    }

    public void setPjpsn(String pjpsn) {
        this.pjpsn = pjpsn;
    }
    public String getVdef1() {
        return vdef1;
    }

    public void setVdef1(String vdef1) {
        this.vdef1 = vdef1;
    }
    public String getVdef10() {
        return vdef10;
    }

    public void setVdef10(String vdef10) {
        this.vdef10 = vdef10;
    }
    public String getVdef2() {
        return vdef2;
    }

    public void setVdef2(String vdef2) {
        this.vdef2 = vdef2;
    }
    public String getVdef3() {
        return vdef3;
    }

    public void setVdef3(String vdef3) {
        this.vdef3 = vdef3;
    }
    public String getVdef4() {
        return vdef4;
    }

    public void setVdef4(String vdef4) {
        this.vdef4 = vdef4;
    }
    public String getVdef5() {
        return vdef5;
    }

    public void setVdef5(String vdef5) {
        this.vdef5 = vdef5;
    }
    public String getVdef6() {
        return vdef6;
    }

    public void setVdef6(String vdef6) {
        this.vdef6 = vdef6;
    }
    public String getVdef7() {
        return vdef7;
    }

    public void setVdef7(String vdef7) {
        this.vdef7 = vdef7;
    }
    public String getVdef8() {
        return vdef8;
    }

    public void setVdef8(String vdef8) {
        this.vdef8 = vdef8;
    }
    public String getVdef9() {
        return vdef9;
    }

    public void setVdef9(String vdef9) {
        this.vdef9 = vdef9;
    }
    public String getUseage() {
        return useage;
    }

    public void setUseage(String useage) {
        this.useage = useage;
    }
    
}

==> ejc-credentials-impl-3.0.0-20220608.025626-40-sources.jar: com/ejianc/certify/vo/CorpCertifBVO.java <==
package com.ejianc.certify.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 证件借用配件-表体
 * 
 * @author generator
 * 
 */
public class CorpCertifBVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Integer crowno; // 行号
    private Date ts; // 时间戳
    private Long pkCorpcertify; // 主表主键
    private Long pkCorpcertifapplyB; // 借证申请单子表主键
    private Long pkCertiftype; // 申请证书类别
    private Integer certifnum; // 证书数量
    private String isjyyj; // 1-原件  2-扫描件
    private Long beianArea; // 备案区域(人力公司)
    private Long bjgw; // 报建岗位
    private String ismany; // 能否一证多用
    private String isyz; // 是否需要押证
    private String islock; // 是否锁定
    private String jydate; // 借用日期
    private String planReturnDate; // 预计归还日期
    private String vmemo; // 备注
    private String pjpsn; // 拟用证件，以逗号分隔
    private String vdef1; // 
    private String vdef10; // 
    private String vdef2; // 
    private String vdef3; // 
    private String vdef4; // 
    private String vdef5; // 
    private String vdef6; // 
    private String vdef7; // 
    private String vdef8; // 
    private String vdef9; // 
    private String useage; // 用途
    

    public Integer getCrowno() {
        return crowno;
    }

    public void setCrowno(Integer crowno) {
        this.crowno = crowno;
    }
    public Date getTs() {
        return ts;
    }

    public void setTs(Date ts) {
        this.ts = ts;
    }
    public Long getPkCorpcertify() {
        return pkCorpcertify;
    }

    public void setPkCorpcertify(Long pkCorpcertify) {
        this.pkCorpcertify = pkCorpcertify;
    }
    public Long getPkCorpcertifapplyB() {
        return pkCorpcertifapplyB;
    }

    public void setPkCorpcertifapplyB(Long pkCorpcertifapplyB) {
        this.pkCorpcertifapplyB = pkCorpcertifapplyB;
    }

    @ReferSerialTransfer(referCode = "certifType")
    public Long getPkCertiftype() {
        return pkCertiftype;
    }
    @ReferDeserialTransfer
    public void setPkCertiftype(Long pkCertiftype) {
        this.pkCertiftype = pkCertiftype;
    }

    public Integer getCertifnum() {
        return certifnum;
    }

    public void setCertifnum(Integer certifnum) {
        this.certifnum = certifnum;
    }
    public String getIsjyyj() {
        return isjyyj;
    }

    public void setIsjyyj(String isjyyj) {
        this.isjyyj = isjyyj;
    }

    @ReferSerialTransfer(referCode = "idm-org")
    public Long getBeianArea() {
        return beianArea;
    }
    @ReferDeserialTransfer
    public void setBeianArea(Long beianArea) {
        this.beianArea = beianArea;
    }

    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getBjgw() {
        return bjgw;
    }
    @ReferDeserialTransfer
    public void setBjgw(Long bjgw) {
        this.bjgw = bjgw;
    }

    public String getIsmany() {
        return ismany;
    }

    public void setIsmany(String ismany) {
        this.ismany = ismany;
    }
    public String getIsyz() {
        return isyz;
    }

    public void setIsyz(String isyz) {
        this.isyz = isyz;
    }
    public String getIslock() {
        return islock;
    }

    public void setIslock(String islock) {
        this.islock = islock;
    }
    public String getJydate() {
        return jydate;
    }

    public void setJydate(String jydate) {
        this.jydate = jydate;
    }
    public String getPlanReturnDate() {
        return planReturnDate;
    }

    public void setPlanReturnDate(String planReturnDate) {
        this.planReturnDate = planReturnDate;
    }
    public String getVmemo() {
        return vmemo;
    }

    public void setVmemo(String vmemo) {
        this.vmemo = vmemo;
    }
    public String getPjpsn() {
        return pjpsn;
    }

    public void setPjpsn(String pjpsn) {
        this.pjpsn = pjpsn;
    }
    public String getVdef1() {
        return vdef1;
    }

    public void setVdef1(String vdef1) {
        this.vdef1 = vdef1;
    }
    public String getVdef10() {
        return vdef10;
    }

    public void setVdef10(String vdef10) {
        this.vdef10 = vdef10;
    }
    public String getVdef2() {
        return vdef2;
    }

    public void setVdef2(String vdef2) {
        this.vdef2 = vdef2;
    }
    public String getVdef3() {
        return vdef3;
    }

    public void setVdef3(String vdef3) {
        this.vdef3 = vdef3;
    }
    public String getVdef4() {
        return vdef4;
    }

    public void setVdef4(String vdef4) {
        this.vdef4 = vdef4;
    }
    public String getVdef5() {
        return vdef5;
    }

    public void setVdef5(String vdef5) {
        this.vdef5 = vdef5;
    }
    public String getVdef6() {
        return vdef6;
    }

    public void setVdef6(String vdef6) {
        this.vdef6 = vdef6;
    }
    public String getVdef7() {
        return vdef7;
    }

    public void setVdef7(String vdef7) {
        this.vdef7 = vdef7;
    }
    public String getVdef8() {
        return vdef8;
    }

    public void setVdef8(String vdef8) {
        this.vdef8 = vdef8;
    }
    public String getVdef9() {
        return vdef9;
    }

    public void setVdef9(String vdef9) {
        this.vdef9 = vdef9;
    }
    public String getUseage() {
        return useage;
    }

    public void setUseage(String useage) {
        this.useage = useage;
    }
    
}
